==> spawn-lia-0.1.1.tar.gz: spawn-lia-0.1.1/lia/main.py <==
"""
This is lia's main program.

:author: Julian M. Kleber
"""
import os
import subprocess

import click
from click import echo
from emoji import emojize


@click.group()
def spells() -> None:
    """
    Collection for Lia's spells/methods.
    """
    pass  # pragma: no cover


@click.command()
@click.argument("packagename")
@click.option("-t", default="y", help="If test should be run")
def heal(packagename: str, t: str) -> None:  # pragma: no cover
    """
    One of Lias most basic spells.

    The heal function is a wrapper for the following commands:
        - black
        - autopep8
        - flake8 (with E9, F63, F7 and F82)
        - mypy --strict
       It also runs pylint with the parseable output format to
       make it easier to integrate into CI systems like
       Woodpecker or Codeberg CI.

    :param packagename:str: Used to specify the package name.
    :param o:str: Used to specify if the user wants to run tests or not.

    :doc-author: Julian M. Kleber
    """
    say_message()
    assert t in ["y", "n"], "Plase specify -t as y/n"
    assert os.path.isdir(packagename)
    if not packagename.endswith("/"):
        packagename += "/"
    subprocess.run(["pip freeze > requirements.txt"], shell=True, check=True)
    subprocess.run(["black " + packagename], shell=True, check=True)
    subprocess.run(
        [
            f"find . -type f -wholename '{packagename}/*.py' "
            "-exec sed --in-place 's/[[:space:]]\+$//' "
            + "{} \+ #sanitize trailing whitespace"
        ],
        shell=True,
        check=True,
    )
    subprocess.run(
        [f"autopep8 --in-place --recursive {packagename}"], shell=True, check=True
    )
    subprocess.run(
        [
            f"python -m flake8 {packagename} --count --select=E9,F63,F7,F82"
            " --show-source --statistics"
        ],
        shell=True,
        check=True,
    )
    subprocess.run([f"mypy --strict {packagename}"], shell=True, check=True)
    subprocess.run(
        [f"python -m pylint -f parseable {packagename}"], shell=True, check=True
    )
    subprocess.run(
        [f"prettify-py format-dir {packagename}"], shell=True, check=True)
    if t == "y":
        subprocess.run(["python -m pytest tests/"], shell=True, check=True)


@click.command()
@click.option("-t", default="y", help="If test should be run")
def deploy(t: str) -> None:
    """
    Deployment routine

    :author: Julian M. Kleber
    """
    say_message()
    if t == "y":
        out = subprocess.run(
            ["python -m pytest tests/"], shell=True, check=True, capture_output=True
        )
        assert "FAILED" not in str(out)
    if os.path.isdir("dist") is True:
        subprocess.run(["rm -r dist "], shell=True, check=True)
    if os.path.isdir("build") is True:
        subprocess.run(["rm -r build"], shell=True, check=True)
    subprocess.run(["python3 -m build"], shell=True, check=True)
    subprocess.run(["twine check dist/*"], shell=True, check=True)
    subprocess.run(["python3 -m twine upload dist/*"], shell=True, check=True)


def say_message() -> None:

    anatomical_heart = emojize(":anatomical heart:")
    mechanical_arm = emojize(":mechanical_arm:")
    call_me_hand = emojize(":call_me_hand:")
    sailing_ship = emojize(":sailboat:")

    message = (
        f"{anatomical_heart} Lia is an open-source CI/CD tool "
        f"that eliminates the Fel {mechanical_arm}"
        f" Copyright © 2023 Soul Twin Records {call_me_hand}, "
        f"a subsidiary of SailBlack Inc. {sailing_ship}"
    )
    echo(message=message)


spells.add_command(heal)
spells.add_command(deploy)

if __name__ == "__main__":
    spells()

==> spawn-lia-0.1.2.tar.gz: spawn-lia-0.1.2/lia/main.py <==
"""
This is lia's main program.

:author: Julian M. Kleber
"""
import os
import subprocess

import click
from click import echo
from emoji import emojize


@click.group()
def spells() -> None:
    """
    Collection for Lia's spells/methods.
    """
    pass  # pragma: no cover


@click.command()
@click.argument("packagename")
@click.option("-t", default="y", help="If test should be run")
def heal(packagename: str, t: str) -> None:  # pragma: no cover
    """
    One of Lias most basic spells.

    The heal function is a wrapper for the following commands:
        - black
        - autopep8
        - flake8 (with E9, F63, F7 and F82)
        - mypy --strict
       It also runs pylint with the parseable output format to
       make it easier to integrate into CI systems like
       Woodpecker or Codeberg CI.

    :param packagename:str: Used to specify the package name.
    :param o:str: Used to specify if the user wants to run tests or not.

    :doc-author: Julian M. Kleber
    """
    say_message()
    assert t in ["y", "n"], "Plase specify -t as y/n"
    assert os.path.isdir(packagename)
    if not packagename.endswith("/"):
        packagename += "/"
    subprocess.run(["pip freeze > requirements.txt"], shell=True, check=True)
    subprocess.run(["black " + packagename], shell=True, check=True)
    subprocess.run(
        [
            f"find . -type f -wholename '{packagename}/*.py' "
            "-exec sed --in-place 's/[[:space:]]\+$//' "
            + "{} \+ #sanitize trailing whitespace"
        ],
        shell=True,
        check=True,
    )
    subprocess.run(
        [f"autopep8 --in-place --recursive {packagename}"], shell=True, check=True
    )
    subprocess.run(
        [
            f"python -m flake8 {packagename} --count --select=E9,F63,F7,F82"
            " --show-source --statistics"
        ],
        shell=True,
        check=True,
    )
    subprocess.run([f"mypy --strict {packagename}"], shell=True, check=True)
    subprocess.run(
        [f"python -m pylint -f parseable {packagename}"], shell=True, check=True
    )
    subprocess.run(
        [f"prettify-py format-dir {packagename}"], shell=True, check=True)
    if t == "y":
        subprocess.run(["python -m pytest tests/"], shell=True, check=True)


@click.command()
@click.option("-t", default="y", help="If test should be run")
def deploy(t: str) -> None:
    """
    Deployment routine

    :author: Julian M. Kleber
    """
    say_message()
    if t == "y":
        out = subprocess.run(
            ["python -m pytest tests/"], shell=True, check=True, capture_output=True
        )
        assert "FAILED" not in str(out)
    if os.path.isdir("dist") is True:
        subprocess.run(["rm -r dist "], shell=True, check=True)
    if os.path.isdir("build") is True:
        subprocess.run(["rm -r build"], shell=True, check=True)
    subprocess.run(["python3 -m build"], shell=True, check=True)
    subprocess.run(["twine check dist/*"], shell=True, check=True)
    subprocess.run(["python3 -m twine upload dist/*"], shell=True, check=True)


def say_message() -> None:

    anatomical_heart = emojize(":anatomical_heart:")
    mechanical_arm = emojize(":mechanical_arm:")
    call_me_hand = emojize(":call_me_hand:")
    sailing_ship = emojize(":sailboat:")

    message = (
        f"{anatomical_heart} Lia is an open-source CI/CD tool "
        f"that eliminates the Fel {mechanical_arm}\n"
        f" Copyright © 2023 Soul Twin Records {call_me_hand}, "
        f"a subsidiary of SailBlack Inc. {sailing_ship}"
    )
    echo(message=message)


spells.add_command(heal)
spells.add_command(deploy)

if __name__ == "__main__":
    spells()
